@@ -47,7 +47,8 @@ def predict_encoding(file_path: str, n_lines: int = 20) -> str:
 
 
 def convert_utf8(path_to_watch: str) -> None:
-    """_summary_
+    """convertit tous les fichiers qui ne sont pas encodés en UTF-8.
+
 
     Args:
         path_to_watch (str): _description_
@@ -92,8 +93,7 @@ def convert_utf8(path_to_watch: str) -> None:
 
 
 def initilisation(path_to_watch: str) -> list:
-    """Initialisation
-
+    """Initialisation: récupère les répertoires dans un chemin donné.
     Args:
         path_to_watch (str): path to watch
 
@@ -108,7 +108,7 @@ def initilisation(path_to_watch: str) -> list:
 
 
 def get_files(paths: list) -> list[dict]:
-    """_summary_
+    """récupère tous les fichiers .tex dans les répertoires donnés.
 
     Args:
         paths (list): _description_
@@ -135,7 +135,7 @@ def get_files(paths: list) -> list[dict]:
 
 
 def clean_aux(paths: list) -> None:
-    """Remove aux files
+    """nettoie les fichiers auxiliaires produits par le compilateur LaTeX.
 
     Args:
         paths (list): _description_
@@ -212,14 +212,23 @@ def define_latex_engine(args: argparse) -> str:
         return "xelatex"
 
 
-def slugify_files(path_to_watch: str):
+def slugify_files(path_to_watch: str,automatique=False):
     """_summary_
 
     Args:
         path_to_watch (str): _description_
     """
     rename = False
+    if not automatique:
+        print("Renommage automatique ?")
+        entree = input("[O]ui, non par defaut: ")
+        if entree.upper() == "O":
+            automatique = True
+            entree = "O"
+        else:
+            automatique = False
     for (root, dirs, file) in os.walk(path_to_watch):
+
         for dir in dirs:
             if (
                 ".git" not in root
@@ -230,44 +239,53 @@ def slugify_files(path_to_watch: str):
                 and "dist" not in root
                 and "latexcor" not in root
                 and "latexcor" not in dir
+                and "site" not in root
+                and "site" not in dir
             ):
 
                 # print(root, dir, slugify(dir))
                 # print(os.path.join(root, dir))
                 # print(os.path.join(root, slugify(dir)))
                 if os.path.join(root, dir) != os.path.join(root, slugify(dir)):
-                    print(f"Renommage de {dir} en {slugify(dir)} ?")
-                    entree = input("[O]ui, non par défaut: ")
-                    if entree.upper() == "O":
-                        print("renommage")
+                    if not automatique:
+                        print(f"Renommage de {dir} en {slugify(dir)} ?")
+                        entree = input("[O]ui, non par défaut: ")
+                    if automatique or entree.upper() == "O":
+                        print(f"Renommage de {dir} en {slugify(dir)}")
                         rename = True
                         os.rename(
                             os.path.join(root, dir), os.path.join(root, slugify(dir))
                         )
     if rename:
-        print("Un ou plusieurs renommages de dossiers ont été effectués.")
-        print("Il est nécessaire de relancer le script pour terminer le renommage.")
-        print("Voulez-vous le relancer maintenant ?")
-        entree = input("[O]ui, non par défaut: ")
-        if entree.upper() == "O":
-            slugify_files(path_to_watch)
+        if not automatique:
+            print("Un ou plusieurs renommages de dossiers ont été effectués.")
+            print("Il est nécessaire de relancer le script pour terminer le renommage.")
+            print("Voulez-vous le relancer maintenant ?")
+            entree = input("[O]ui, non par défaut: ")
+        if automatique or entree.upper() == "O":
+            slugify_files(path_to_watch,automatique)
     else:
-        print("Aucun dosssier à renommer")
+        print("Renommage des dossiers terminé.")
 
     for (root, dirs, files) in os.walk(path_to_watch):
         for file in files:
-            if ".tex" in file or ".pdf" in file or ".ipybn" in file:
+            if ".tex" in file or ".pdf" in file or ".ipynb" in file:
                 filename, file_extension = os.path.splitext(file)
                 if filename != slugify(filename):
-                    print(f"Renommer {file} en {slugify(filename) + file_extension} ?")
+                    if not automatique:
+                        print(
+                            f"Renommer {file} en {slugify(filename) + file_extension} ?"
+                        )
 
-                    # print(filename)
-                    # print(file_extension)
-                    # print(os.path.join(root, file))
-                    # print(os.path.join(root, slugify(filename) + file_extension))
-                    entree = input("[O]ui, non par défaut: ")
-                    if entree.upper() == "O":
-                        print("renommage")
+                        # print(filename)
+                        # print(file_extension)
+                        # print(os.path.join(root, file))
+                        # print(os.path.join(root, slugify(filename) + file_extension))
+                        entree = input("[O]ui, non par défaut: ")
+                    if automatique or entree.upper() == "O":
+                        print(
+                            f"{file} en {slugify(filename) + file_extension}"
+                        )
                         rename = True
                         os.rename(
                             os.path.join(root, file),
